"""
Django Server Tag Package

A Django package to fetch and render scripts from a remote URL with template tag integration.
"""

__version__ = '1.0.0'
__author__ = 'Adunblock'

default_app_config = 'server_tag.apps.ServerTagConfig'